The [control](control) folder is a slightly modified version of
[python-control](http://sourceforge.net/apps/mediawiki/python-control) by
Richard Murray.  The modifications are in
[src/freqplot.py](control/src/freqplot.py) and [setup.py](setup.py) and are
marked with "ModelicaRes".
